[![Test](https://github.com/IzeBerg/wgus/actions/workflows/test.yml/badge.svg)](https://github.com/IzeBerg/wgus/actions/workflows/test.yml)
[![codecov](https://codecov.io/gh/IzeBerg/wgus/branch/main/graph/badge.svg?token=FMXTYNXAIH)](https://codecov.io/gh/IzeBerg/wgus)
<a href="https://pypi.org/project/wgus" target="_blank">
    <img src="https://img.shields.io/pypi/v/wgus?color=%2334D058&label=pypi%20package" alt="Package version">
</a>
<a href="https://pypi.org/project/wgus" target="_blank">
    <img src="https://img.shields.io/pypi/pyversions/wgus.svg?color=%2334D058" alt="Supported Python versions">
</a>

API for Wargaming Update Service (WGUS)